@@ -9,11 +9,14 @@ def main():
     import sys
 
     args = argparse.ArgumentParser(description='The reference compiler for the Crowbar programming language')
-    args.add_argument('-V', '--version', action='version', version='%(prog)s 0.0.4')
+    args.add_argument('-V', '--version', action='version', version='%(prog)s 0.0.5')
     args.add_argument('-g', '--include-debug-info', action='store_true')
     args.add_argument('--stop-at-parse-tree', action='store_true')
     args.add_argument('--stop-at-qbe-ssa', action='store_true')
     args.add_argument('-S', '--stop-at-assembly', action='store_true')
+    args.add_argument('-c', '--stop-at-object', action='store_true')
+    args.add_argument('-D', '--define-constant', help='define a constant with some literal value')
+    args.add_argument('-I', '--include-dir', help='folder to look for included headers within')
     args.add_argument('-o', '--out', help='output file')
     args.add_argument('input', help='input file')
 
@@ -38,20 +41,23 @@ def main():
     # TODO bundle the qbe binary or something
     qbe_result = subprocess.run(['qbe', '-'], input=ssa, capture_output=True, text=True)
     if qbe_result.returncode != 0:
-        if args.out is None:
-            args.out = args.input.replace('.cro', '.s')
         print(qbe_result.stderr, file=sys.stderr)
         sys.exit(1)
     asm = qbe_result.stdout
     if args.stop_at_assembly:
         if args.out is None:
-            args.out = args.input.replace('.cro', '.o')
+            args.out = args.input.replace('.cro', '.s')
         with open(args.out, 'w', encoding='utf-8') as output_file:
             output_file.write(asm)
         return
     if args.out is None:
         args.out = args.input.replace('.cro', '.out')
     # TODO don't assume gcc is always the right thing
+    extra_gcc_flags = []
+    if args.stop_at_object:
+        if args.out is None:
+            args.out = args.input.replace('.cro', '.o')
+        extra_gcc_flags.append('-c')
     gcc_result = subprocess.run(['gcc', '-x', 'assembler', '-o', args.out, '-'], input=asm, text=True)
     sys.exit(gcc_result.returncode)
 
